@@ -134,7 +134,7 @@ class Drush:
         self._verbose = verbose
         self._stdout = stdout
 
-        if isdir(self._path):
+        if isdir(self._path) and isdir(path_join(self._path, 'sites')):
             with pushd(self._path):
                 site_dirs = [x
                             for x in os.listdir('sites')
@@ -173,6 +173,9 @@ class Drush:
                 sp.check_call(command_line, stdout=self._stdout)
 
     def add_uri(self, uri):
+        if uri in self._uris:
+            return
+
         self._uris.append(uri)
 
     def init_dir(self, major_version=7, minor_version=24, cache=True):
